[ARVADOS] updated: db2411a5e8b0dab503a4f712e14c65ef33947a62

git at public.curoverse.com git at public.curoverse.com
Tue Nov 4 08:58:51 EST 2014


Summary of changes:
 apps/workbench/test/integration/pipeline_instances_test.rb | 6 +++---
 services/api/test/fixtures/pipeline_instances.yml          | 6 +++---
 2 files changed, 6 insertions(+), 6 deletions(-)

       via  db2411a5e8b0dab503a4f712e14c65ef33947a62 (commit)
      from  963f0bf8fc030052aea9a7fcd89ca6ef88967c96 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.


commit db2411a5e8b0dab503a4f712e14c65ef33947a62
Author: Phil Hodgson <bitbucket at philhodgson.net>
Date:   Tue Nov 4 14:58:44 2014 +0100

    3618: accommodate new fixture indexing in pipeline_instance tests (including run-time=0 test)

diff --git a/services/api/test/fixtures/pipeline_instances.yml b/services/api/test/fixtures/pipeline_instances.yml
index 0317db3..e086f77 100644
--- a/services/api/test/fixtures/pipeline_instances.yml
+++ b/services/api/test/fixtures/pipeline_instances.yml
@@ -161,9 +161,9 @@ pipeline_<%=i%>_of_10:
   state: Failed
   uuid: zzzzz-d1hrv-10pipelines0<%= i.to_s.rjust(3, '0') %>
   owner_uuid: zzzzz-j7d0g-000010pipelines
-  created_at: <%= (2*i).hour.ago.to_s(:db) %>
-  started_at: <%= (2*i).hour.ago.to_s(:db) %>
-  finished_at: <%= i.minute.ago.to_s(:db) %>
+  created_at: <%= (2*(i-1)).hour.ago.to_s(:db) %>
+  started_at: <%= (2*(i-1)).hour.ago.to_s(:db) %>
+  finished_at: <%= (i-1).minute.ago.to_s(:db) %>
   components:
     foo:
       script: foo

-----------------------------------------------------------------------


hooks/post-receive
diff --git a/apps/workbench/test/integration/pipeline_instances_test.rb b/apps/workbench/test/integration/pipeline_instances_test.rb
index 023771a..6312546 100644
--- a/apps/workbench/test/integration/pipeline_instances_test.rb
+++ b/apps/workbench/test/integration/pipeline_instances_test.rb
@@ -340,11 +340,11 @@ class PipelineInstancesTest < ActionDispatch::IntegrationTest
   end
 
   [
-    [1, 1*60*60 + 59*60], # run time 1 hour 59 minutes
-    [10, 19*60*60 + 50*60], # run time 19 hours and 50 minutes
+    [1, 0], # run time 0 minutes
+    [10, 17*60*60 + 51*60], # run time 17 hours and 51 minutes
   ].each do |index, run_time|
     test "pipeline start and finish time display #{index}" do
-      visit page_with_token("user1_with_load", "/pipeline_instances/zzzzz-d1hrv-10pipelines0#{(index).to_s.rjust(3, '0')}")
+      visit page_with_token("user1_with_load", "/pipeline_instances/zzzzz-d1hrv-10pipelines0#{index.to_s.rjust(3, '0')}")
 
       assert page.has_text? 'This pipeline started at'
       page_text = page.text
-- 




More information about the arvados-commits mailing list